// Parameters in cm
r0 = 0.04;      // the hole radius
tC = 0.005;     // copper thickness
tCa = 0.05;	// cathode thickness
tA = 0.05;	// anode thickness
tD = 0.3;     	// dielectric thickness
lE = tD/2+2.0;  // distance from hole center to anode 
a = 1.5;	// radius dielectric, copper plate, anode, cathode

// Characteristic lengths
lcDielectricHole = 0.005;
lcDielectric = 0.1;
lcEtchingHole = 0.005;
lcVolume = 0.05; 
lcCopperPlateBdry = 0.1;
lcAnode = 0.1;
lcCathode = 0.1;

// ------------------------------------------------------------
// Hole
// ------------------------------------------------------------


// *******************************
// Center
// *******************************
pc1 = newp; Point(pc1) = {0, 0, tD/2,lcDielectricHole};
pc2 = newp; Point(pc2) = {0, 0, -1*tD/2,lcDielectricHole};
pc3 = newp; Point(pc3) = {0, 0, (2*tC+tD)/2,lcDielectricHole};
pc4 = newp; Point(pc4) = {0, 0, -1*(2*tCa+tD)/2,lcCathode};
pc5 = newp; Point(pc5) = {0, 0, lE,lcAnode};
pc6 = newp; Point(pc6) = {0, 0, lE+tA,lcAnode};

// *******************************
// Dielectric hole
// *******************************
// Top
pth1 = newp; Point(pth1) = {r0, 0, tD/2,lcDielectricHole};
pth2 = newp; Point(pth2) = {0, r0, tD/2,lcDielectricHole};
pth3 = newp; Point(pth3) = {-r0, 0, tD/2,lcDielectricHole};
pth4 = newp; Point(pth4) = {0, -r0, tD/2,lcDielectricHole};

cth1 = newc; Circle(cth1) = {pth1, pc1, pth2};
cth2 = newc; Circle(cth2) = {pth2, pc1, pth3};
cth3 = newc; Circle(cth3) = {pth3, pc1, pth4};
cth4 = newc; Circle(cth4) = {pth4, pc1, pth1};

// Bottom
pbh1 = newp; Point(pbh1) = {r0, 0, -1*tD/2,lcDielectricHole};
pbh2 = newp; Point(pbh2) = {0, r0, -1*tD/2,lcDielectricHole};
pbh3 = newp; Point(pbh3) = {-r0,0 , -1*tD/2,lcDielectricHole};
pbh4 = newp; Point(pbh4) = {0, -r0, -1*tD/2,lcDielectricHole};

// Circular boundary bottom
cbh1 = newc; Circle(cbh1) = {pbh1, pc2, pbh2};
cbh2 = newc; Circle(cbh2) = {pbh2, pc2, pbh3};
cbh3 = newc; Circle(cbh3) = {pbh3, pc2, pbh4};
cbh4 = newc; Circle(cbh4) = {pbh4, pc2, pbh1};

// lines connecting top and bottom
lconnd1 = newc; Line(lconnd1) = {pth1, pbh1};
lconnd2 = newc; Line(lconnd2) = {pth2, pbh2};
lconnd3 = newc; Line(lconnd3) = {pth3, pbh3};
lconnd4 = newc; Line(lconnd4) = {pth4, pbh4};

// *******************************
// Upper Etching
// *******************************

// Top
ptue1 = newp; Point(ptue1) = {r0, 0, (2*tC+tD)/2,lcEtchingHole};
ptue2 = newp; Point(ptue2) = {0, r0, (2*tC+tD)/2,lcEtchingHole};
ptue3 = newp; Point(ptue3) = {-r0, 0, (2*tC+tD)/2,lcEtchingHole};
ptue4 = newp; Point(ptue4) = {0, -r0, (2*tC+tD)/2,lcEtchingHole};

// Bottom = points for dielectricum top
// pbue1 = newp; Point(pbue1) = {r0, 0, tD/2,lcEtchingHole};
// pbue2 = newp; Point(pbue2) = {0, r0, tD/2,lcEtchingHole};
// pbue3 = newp; Point(pbue3) = {-r0, 0, tD/2,lcEtchingHole};
// pbue4 = newp; Point(pbue4) = {0, -r0, tD/2,lcEtchingHole};

// Circular boundary top
ctue1 = newc; Circle(ctue1) = {ptue1, pc3, ptue2};
ctue2 = newc; Circle(ctue2) = {ptue2, pc3, ptue3};
ctue3 = newc; Circle(ctue3) = {ptue3, pc3, ptue4};
ctue4 = newc; Circle(ctue4) = {ptue4, pc3, ptue1};

// Circular boundary bottom
cbue1 = newc; Circle(cbue1) = {pth1, pc1, pth2};
cbue2 = newc; Circle(cbue2) = {pth2, pc1, pth3};
cbue3 = newc; Circle(cbue3) = {pth3, pc1, pth4};
cbue4 = newc; Circle(cbue4) = {pth4, pc1, pth1};

// lines connecting top and bottom
lconnue1 = newc; Line(lconnue1) = {ptue1, pth1};
lconnue2 = newc; Line(lconnue2) = {ptue2, pth2};
lconnue3 = newc; Line(lconnue3) = {ptue3, pth3};
lconnue4 = newc; Line(lconnue4) = {ptue4, pth4};

// *******************************
// Lower Etching
// *******************************

// Top
ptle1 = newp; Point(ptle1) = {r0, 0, -1*tD/2,lcEtchingHole};
ptle2 = newp; Point(ptle2) = {0, r0, -1*tD/2,lcEtchingHole};
ptle3 = newp; Point(ptle3) = {-r0, 0, -1*tD/2,lcEtchingHole};
ptle4 = newp; Point(ptle4) = {0, -r0, -1*tD/2,lcEtchingHole};

// Bottom
pble1 = newp; Point(pble1) = {r0, 0, -1*(2*tCa+tD)/2,lcEtchingHole};
pble2 = newp; Point(pble2) = {0, r0, -1*(2*tCa+tD)/2,lcEtchingHole};
pble3 = newp; Point(pble3) = {-r0, 0, -1*(2*tCa+tD)/2,lcEtchingHole};
pble4 = newp; Point(pble4) = {0, -r0, -1*(2*tCa+tD)/2,lcEtchingHole};

// Circular boundary top
ctle1 = newc; Circle(ctle1) = {ptle1, pc2, ptle2};
ctle2 = newc; Circle(ctle2) = {ptle2, pc2, ptle3};
ctle3 = newc; Circle(ctle3) = {ptle3, pc2, ptle4};
ctle4 = newc; Circle(ctle4) = {ptle4, pc2, ptle1};

// Circular boundary bottom
cble1 = newc; Circle(cble1) = {pble1, pc4, pble2};
cble2 = newc; Circle(cble2) = {pble2, pc4, pble3};
cble3 = newc; Circle(cble3) = {pble3, pc4, pble4};
cble4 = newc; Circle(cble4) = {pble4, pc4, pble1};

// lines connecting top and bottom
lconnle1 = newc; Line(lconnle1) = {ptle1, pble1};
lconnle2 = newc; Line(lconnle2) = {ptle2, pble2};
lconnle3 = newc; Line(lconnle3) = {ptle3, pble3};
lconnle4 = newc; Line(lconnle4) = {ptle4, pble4};

// *******************************************************
// Dielectric
// *******************************************************

// Top points
pdt1 = newp; Point(pdt1) = {a, 0, tD/2,lcDielectric};
pdt2 = newp; Point(pdt2) = {0, a, tD/2,lcDielectric};
pdt3 = newp; Point(pdt3) = {-a, 0, tD/2,lcDielectric};
pdt4 = newp; Point(pdt4) = {0, -a, tD/2,lcDielectric};

// Bottom points
pdb1 = newp; Point(pdb1) = {a, 0, -tD/2,lcDielectric};
pdb2 = newp; Point(pdb2) = {0, a, -tD/2,lcDielectric};
pdb3 = newp; Point(pdb3) = {-a, 0, -tD/2,lcDielectric};
pdb4 = newp; Point(pdb4) = {0, -a, -tD/2,lcDielectric};

// Circular boundaries top
cbdt1 = newc; Circle(cbdt1) = {pdt1, pc1, pdt2};
cbdt2 = newc; Circle(cbdt2) = {pdt2, pc1, pdt3};
cbdt3 = newc; Circle(cbdt3) = {pdt3, pc1, pdt4};
cbdt4 = newc; Circle(cbdt4) = {pdt4, pc1, pdt1};

// Circular boundaries bottom
cbdb1 = newc; Circle(cbdb1) = {pdb1, pc2, pdb2};
cbdb2 = newc; Circle(cbdb2) = {pdb2, pc2, pdb3};
cbdb3 = newc; Circle(cbdb3) = {pdb3, pc2, pdb4};
cbdb4 = newc; Circle(cbdb4) = {pdb4, pc2, pdb1};

// Connect the upper and lower points with lines to form the plate
ldt1 = newc; Line(ldt1) = {pdt1, pdb1};
ldt2 = newc; Line(ldt2) = {pdt2, pdb2};
ldt3 = newc; Line(ldt3) = {pdt3, pdb3};
ldt4 = newc; Line(ldt4) = {pdt4, pdb4};

// Lines connecting outer circle points with inner circle points - top
// already the bottom lines from the copper plate

// Lines connecting outer circle points with inner circle points - bottom
lconnbdhole1 = newc; Line(lconnbdhole1) = {pdb1, pbh1};
lconnbdhole2 = newc; Line(lconnbdhole2) = {pdb2, pbh2};
lconnbdhole3 = newc; Line(lconnbdhole3) = {pdb3, pbh3};
lconnbdhole4 = newc; Line(lconnbdhole4) = {pdb4, pbh4};

// *******************************************************
// Copper planes
// *******************************************************

// Top Points
pcpt1 = newp; Point(pcpt1) = {a, 0, tD/2+tC,lcCopperPlateBdry};
pcpt2 = newp; Point(pcpt2) = {0, a, tD/2+tC,lcCopperPlateBdry};
pcpt3 = newp; Point(pcpt3) = {-a, 0, tD/2+tC,lcCopperPlateBdry};
pcpt4 = newp; Point(pcpt4) = {0, -a, tD/2+tC,lcCopperPlateBdry};

// Circular boundary top
ccpt1 = newc; Circle(ccpt1) = {pcpt1, pc3, pcpt2};
ccpt2 = newc; Circle(ccpt2) = {pcpt2, pc3, pcpt3};
ccpt3 = newc; Circle(ccpt3) = {pcpt3, pc3, pcpt4};
ccpt4 = newc; Circle(ccpt4) = {pcpt4, pc3, pcpt1};

// lines connecting top and bottom
lconncp1 = newc; Line(lconncp1) = {pcpt1, pdt1};
lconncp2 = newc; Line(lconncp2) = {pcpt2, pdt2};
lconncp3 = newc; Line(lconncp3) = {pcpt3, pdt3};
lconncp4 = newc; Line(lconncp4) = {pcpt4, pdt4};

// Lines connecting outer circle points with inner circle points - top
lconntcphole1 = newc; Line(lconntcphole1) = {pcpt1, ptue1};
lconntcphole2 = newc; Line(lconntcphole2) = {pcpt2, ptue2};
lconntcphole3 = newc; Line(lconntcphole3) = {pcpt3, ptue3};
lconntcphole4 = newc; Line(lconntcphole4) = {pcpt4, ptue4};

// Lines connecting outer circle points with inner circle points - bottom
lconnbcphole1 = newc; Line(lconnbcphole1) = {pdt1, pth1};
lconnbcphole2 = newc; Line(lconnbcphole2) = {pdt2, pth2};
lconnbcphole3 = newc; Line(lconnbcphole3) = {pdt3, pth3};
lconnbcphole4 = newc; Line(lconnbcphole4) = {pdt4, pth4};

// *******************************************************
// Cathode
// *******************************************************

// Top points are bottom points from dielectric

// Bottom Points
pcab1 = newp; Point(pcab1) = {a, 0, -1*(2*tCa+tD)/2,lcCathode};
pcab2 = newp; Point(pcab2) = {0, a, -1*(2*tCa+tD)/2,lcCathode};
pcab3 = newp; Point(pcab3) = {-a, 0, -1*(2*tCa+tD)/2,lcCathode};
pcab4 = newp; Point(pcab4) = {0, -a, -1*(2*tCa+tD)/2,lcCathode};

// Circular boundary bottom
ccab1 = newc; Circle(ccab1) = {pcab1, pc4, pcab2};
ccab2 = newc; Circle(ccab2) = {pcab2, pc4, pcab3};
ccab3 = newc; Circle(ccab3) = {pcab3, pc4, pcab4};
ccab4 = newc; Circle(ccab4) = {pcab4, pc4, pcab1};

// lines connecting top and bottom
lconnca1 = newc; Line(lconnca1) = {pcab1, pdb1};
lconnca2 = newc; Line(lconnca2) = {pcab2, pdb2};
lconnca3 = newc; Line(lconnca3) = {pcab3, pdb3};
lconnca4 = newc; Line(lconnca4) = {pcab4, pdb4};



// *******************************************************
// Anode
// *******************************************************

// Top Points
pat1 = newp; Point(pat1) = {a, 0, lE+tA,lcAnode};
pat2 = newp; Point(pat2) = {0, a, lE+tA,lcAnode};
pat3 = newp; Point(pat3) = {-a, 0, lE+tA,lcAnode};
pat4 = newp; Point(pat4) = {0, -a, lE+tA,lcAnode};

// Circular boundary top
cpat1 = newc; Circle(cpat1) = {pat1, pc6, pat2};
cpat2 = newc; Circle(cpat2) = {pat2, pc6, pat3};
cpat3 = newc; Circle(cpat3) = {pat3, pc6, pat4};
cpat4 = newc; Circle(cpat4) = {pat4, pc6, pat1};

// Bottom Points
pab1 = newp; Point(pab1) = {a, 0, lE,lcAnode};
pab2 = newp; Point(pab2) = {0, a, lE,lcAnode};
pab3 = newp; Point(pab3) = {-a, 0, lE,lcAnode};
pab4 = newp; Point(pab4) = {0, -a, lE,lcAnode};

// Circular boundary bottom
cpab1 = newc; Circle(cpab1) = {pab1, pc5, pab2};
cpab2 = newc; Circle(cpab2) = {pab2, pc5, pab3};
cpab3 = newc; Circle(cpab3) = {pab3, pc5, pab4};
cpab4 = newc; Circle(cpab4) = {pab4, pc5, pab1};

// lines connecting top and bottom
lconna1 = newc; Line(lconna1) = {pat1, pab1};
lconna2 = newc; Line(lconna2) = {pat2, pab2};
lconna3 = newc; Line(lconna3) = {pat3, pab3};
lconna4 = newc; Line(lconna4) = {pat4, pab4};

// lines connecting top of copper plate and bottom of anode
lconnv1 = newc; Line(lconnv1) = {pcpt1, pab1};
lconnv2 = newc; Line(lconnv2) = {pcpt2, pab2};
lconnv3 = newc; Line(lconnv3) = {pcpt3, pab3};
lconnv4 = newc; Line(lconnv4) = {pcpt4, pab4};

// *************************************************
// Define surfaces and volumes
// *************************************************

// Copper plate
// Copper plate
// Copper plate

// defining all single surfaces by looping lines, then loop all surfaces to merged ruled surfaces or plane surfaces, then to one volume

// rim (outer surface) made of 4 ruled surfaces

llcp_out_rim1 = newreg; Line Loop(llcp_out_rim1) = {-lconncp1, ccpt1, lconncp2, -cbdt1};
rscp_out_rim1 = newreg; Ruled Surface(rscp_out_rim1) = {llcp_out_rim1};

llcp_out_rim2 = newreg; Line Loop(llcp_out_rim2) = {-lconncp2, ccpt2, lconncp3, -cbdt2};
rscp_out_rim2 = newreg; Ruled Surface(rscp_out_rim2) = {llcp_out_rim2};

llcp_out_rim3 = newreg; Line Loop(llcp_out_rim3) = {-lconncp3, ccpt3, lconncp4, -cbdt3};
rscp_out_rim3 = newreg; Ruled Surface(rscp_out_rim3) = {llcp_out_rim3};

llcp_out_rim4 = newreg; Line Loop(llcp_out_rim4) = {-lconncp4, ccpt4, lconncp1, -cbdt4};
rscp_out_rim4 = newreg; Ruled Surface(rscp_out_rim4) = {llcp_out_rim4};

// top plane surface - made of 4 quarter ring segments (upper copper plate with hole)

llcp_up_ps1 = newreg; Line Loop(llcp_up_ps1) = {-ccpt1, lconntcphole1, ctue1, -lconntcphole2};
pscp_up1 = newreg; Plane Surface(pscp_up1) = {llcp_up_ps1};

llcp_up_ps2 = newreg; Line Loop(llcp_up_ps2) = {-ccpt2, lconntcphole2, ctue2, -lconntcphole3};
pscp_up2 = newreg; Plane Surface(pscp_up2) = {llcp_up_ps2};

llcp_up_ps3 = newreg; Line Loop(llcp_up_ps3) = {-ccpt3, lconntcphole3, ctue3, -lconntcphole4};
pscp_up3 = newreg; Plane Surface(pscp_up3) = {llcp_up_ps3};

llcp_up_ps4 = newreg; Line Loop(llcp_up_ps4) = {-ccpt4, lconntcphole4, ctue4, -lconntcphole1};
pscp_up4 = newreg; Plane Surface(pscp_up4) = {llcp_up_ps4};

// rim (inner surface)

llcp_in_rim1 = newreg; Line Loop(llcp_in_rim1) = {-lconnue1, ctue1, lconnue2, -cbue1};
rscp_in_rim1 = newreg; Ruled Surface(rscp_in_rim1) = {llcp_in_rim1};

llcp_in_rim2 = newreg; Line Loop(llcp_in_rim2) = {-lconnue2, ctue2, lconnue3, -cbue2};
rscp_in_rim2 = newreg; Ruled Surface(rscp_in_rim2) = {llcp_in_rim2};

llcp_in_rim3 = newreg; Line Loop(llcp_in_rim3) = {-lconnue3, ctue3, lconnue4, -cbue3};
rscp_in_rim3 = newreg; Ruled Surface(rscp_in_rim3) = {llcp_in_rim3};

llcp_in_rim4 = newreg; Line Loop(llcp_in_rim4) = {-lconnue4, ctue4, lconnue1, -cbue4};
rscp_in_rim4 = newreg; Ruled Surface(rscp_in_rim4) = {llcp_in_rim4};

// bottom plane surface - made of 4 quarter ring segments (upper copper plate with hole)

llcp_bo_ps1 = newreg; Line Loop(llcp_bo_ps1) = {-cbdt1, lconnbcphole1, cth1, -lconnbcphole2};
pscp_bo1 = newreg; Plane Surface(pscp_bo1) = {llcp_bo_ps1};

llcp_bo_ps2 = newreg; Line Loop(llcp_bo_ps2) = {-cbdt2, lconnbcphole2, cth2, -lconnbcphole3};
pscp_bo2 = newreg; Plane Surface(pscp_bo2) = {llcp_bo_ps2};

llcp_bo_ps3 = newreg; Line Loop(llcp_bo_ps3) = {-cbdt3, lconnbcphole3, cth3, -lconnbcphole4};
pscp_bo3 = newreg; Plane Surface(pscp_bo3) = {llcp_bo_ps3};

llcp_bo_ps4 = newreg; Line Loop(llcp_bo_ps4) = {-cbdt4, lconnbcphole4, cth4, -lconnbcphole1};
pscp_bo4 = newreg; Plane Surface(pscp_bo4) = {llcp_bo_ps4};

// Make copper plate volume:

slcp = newreg; Surface Loop(slcp) = {rscp_out_rim1, rscp_out_rim2, rscp_out_rim3, rscp_out_rim4, pscp_up1, pscp_up2, pscp_up3, pscp_up4, rscp_in_rim1, rscp_in_rim2, rscp_in_rim3, rscp_in_rim4, pscp_bo1, pscp_bo2, pscp_bo3, pscp_bo4};
volcp = newreg; Volume(volcp) = {slcp};

// Dielectric
// Dielectric
// Dielectric

// rim (outer surface) made of 4 ruled surfaces

lld_out_rim1 = newreg; Line Loop(lld_out_rim1) = {-ldt1, cbdt1, ldt2, -cbdb1};
rsd_out_rim1 = newreg; Ruled Surface(rsd_out_rim1) = {lld_out_rim1};

lld_out_rim2 = newreg; Line Loop(lld_out_rim2) = {-ldt2, cbdt2, ldt3, -cbdb2};
rsd_out_rim2 = newreg; Ruled Surface(rsd_out_rim2) = {lld_out_rim2};

lld_out_rim3 = newreg; Line Loop(lld_out_rim3) = {-ldt3, cbdt3, ldt4, -cbdb3};
rsd_out_rim3 = newreg; Ruled Surface(rsd_out_rim3) = {lld_out_rim3};

lld_out_rim4 = newreg; Line Loop(lld_out_rim4) = {-ldt4, cbdt4, ldt1, -cbdb4};
rsd_out_rim4 = newreg; Ruled Surface(rsd_out_rim4) = {lld_out_rim4};

// top plane surface is bottom plane surface from copper plate

// bottom dielectric plate plane surface
lld_bo_ps1 = newreg; Line Loop(lld_bo_ps1) = {-cbdb1, lconnbdhole1, cbh1, -lconnbdhole2};
psd_bo1 = newreg; Plane Surface(psd_bo1) = {lld_bo_ps1};

lld_bo_ps2 = newreg; Line Loop(lld_bo_ps2) = {-cbdb2, lconnbdhole2, cbh2, -lconnbdhole3};
psd_bo2 = newreg; Plane Surface(psd_bo2) = {lld_bo_ps2};

lld_bo_ps3 = newreg; Line Loop(lld_bo_ps3) = {-cbdb3, lconnbdhole3, cbh3, -lconnbdhole4};
psd_bo3 = newreg; Plane Surface(psd_bo3) = {lld_bo_ps3};

lld_bo_ps4 = newreg; Line Loop(lld_bo_ps4) = {-cbdb4, lconnbdhole4, cbh4, -lconnbdhole1};
psd_bo4 = newreg; Plane Surface(psd_bo4) = {lld_bo_ps4};

// inner rim dielectric

lld_in_rim1 = newreg; Line Loop(lld_in_rim1) = {lconnd1, cbh1, -lconnd2, -cth1};
rsd_in_rim1 = newreg; Ruled Surface(rsd_in_rim1) = {lld_in_rim1};

lld_in_rim2 = newreg; Line Loop(lld_in_rim2) = {lconnd2, cbh2, -lconnd3, -cth2};
rsd_in_rim2 = newreg; Ruled Surface(rsd_in_rim2) = {lld_in_rim2};

lld_in_rim3 = newreg; Line Loop(lld_in_rim3) = {lconnd3, cbh3, -lconnd4, -cth3};
rsd_in_rim3 = newreg; Ruled Surface(rsd_in_rim3) = {lld_in_rim3};

lld_in_rim4 = newreg; Line Loop(lld_in_rim4) = {lconnd4, cbh4, -lconnd1, -cth4};
rsd_in_rim4 = newreg; Ruled Surface(rsd_in_rim4) = {lld_in_rim4};

// make Dielectric plate volume

sldp = newreg; Surface Loop(sldp) = {rsd_out_rim1, rsd_out_rim2, rsd_out_rim3, rsd_out_rim4, pscp_bo1, pscp_bo2, pscp_bo3, pscp_bo4, rsd_in_rim1, rsd_in_rim2, rsd_in_rim3, rsd_in_rim4, psd_bo1, psd_bo2, psd_bo3, psd_bo4};
voldp = newreg; Volume(voldp) = {sldp};


// bottom of hole to cathode (plane surface hole bottom - pshb)

llhb = newreg; Line Loop(llhb) = {cbh1, cbh2, cbh3, cbh4};
pshb = newreg; Plane Surface(pshb) = {llhb};

// Cathode
// Cathode
// Cathode

// Bottom Cathode surface

llca_bo = newreg; Line Loop(llca_bo) = {ccab1, ccab2, ccab3, ccab4};
psca_bo = newreg; Plane Surface(psca_bo) = {llca_bo};

// Cathode outer rim

llca_rim1 = newreg; Line Loop(llca_rim1) = {lconnca1, cbdb1, -lconnca2, -ccab1};
rsca_rim1 = newreg; Ruled Surface(rsca_rim1) = {llca_rim1};

llca_rim2 = newreg; Line Loop(llca_rim2) = {lconnca2, cbdb2, -lconnca3, -ccab2};
rsca_rim2 = newreg; Ruled Surface(rsca_rim2) = {llca_rim2};

llca_rim3 = newreg; Line Loop(llca_rim3) = {lconnca3, cbdb3, -lconnca4, -ccab3};
rsca_rim3 = newreg; Ruled Surface(rsca_rim3) = {llca_rim3};

llca_rim4 = newreg; Line Loop(llca_rim4) = {lconnca4, cbdb4, -lconnca1, -ccab4};
rsca_rim4 = newreg; Ruled Surface(rsca_rim4) = {llca_rim4};

// Make cathode volume

slca = newreg; Surface Loop(slca) = {rsca_rim1, rsca_rim2, rsca_rim3, rsca_rim4, psca_bo, pshb, psd_bo1, psd_bo2, psd_bo3, psd_bo4};
volca = newreg; Volume(volca) = {slca};

// Gas volume
// Gas volume
// Gas volume

// outer rim

llg_out_rim1 = newreg; Line Loop(llg_out_rim1) = {-lconnv1, ccpt1, lconnv2, -cpab1};
rsg_out_rim1 = newreg; Ruled Surface(rsg_out_rim1) = {llg_out_rim1};

llg_out_rim2 = newreg; Line Loop(llg_out_rim2) = {-lconnv2, ccpt2, lconnv3, -cpab2};
rsg_out_rim2 = newreg; Ruled Surface(rsg_out_rim2) = {llg_out_rim2};

llg_out_rim3 = newreg; Line Loop(llg_out_rim3) = {-lconnv3, ccpt3, lconnv4, -cpab3};
rsg_out_rim3 = newreg; Ruled Surface(rsg_out_rim3) = {llg_out_rim3};

llg_out_rim4 = newreg; Line Loop(llg_out_rim4) = {-lconnv4, ccpt4, lconnv1, -cpab4};
rsg_out_rim4 = newreg; Ruled Surface(rsg_out_rim4) = {llg_out_rim4};

// Gas volume top plane surface = Anode bottom plane surface

llg_top = newreg; Line Loop(llg_top) = {cpab1, cpab2, cpab3, cpab4};
psg_top = newreg; Plane Surface(psg_top) = {llg_top};

// Make Gas volume volume

slg = newreg; Surface Loop(slg) = {rsg_out_rim1, rsg_out_rim2, rsg_out_rim3, rsg_out_rim4, psg_top, pscp_up1, pscp_up2, pscp_up3, pscp_up4, rscp_in_rim1, rscp_in_rim2, rscp_in_rim3, rscp_in_rim4, rsd_in_rim1, rsd_in_rim2, rsd_in_rim3, rsd_in_rim4, pshb};
volg = newreg; Volume(volg) = {slg};

// Anode
// Anode
// Anode

// outer rim anode

lla_out_rim1 = newreg; Line Loop(lla_out_rim1) = {-lconna1, cpat1, lconna2, -cpab1};
rsa_out_rim1 = newreg; Ruled Surface(rsa_out_rim1) = {lla_out_rim1};

lla_out_rim2 = newreg; Line Loop(lla_out_rim2) = {-lconna2, cpat2, lconna3, -cpab2};
rsa_out_rim2 = newreg; Ruled Surface(rsa_out_rim2) = {lla_out_rim2};

lla_out_rim3 = newreg; Line Loop(lla_out_rim3) = {-lconna3, cpat3, lconna4, -cpab3};
rsa_out_rim3 = newreg; Ruled Surface(rsa_out_rim3) = {lla_out_rim3};

lla_out_rim4 = newreg; Line Loop(lla_out_rim4) = {-lconna4, cpat4, lconna1, -cpab4};
rsa_out_rim4 = newreg; Ruled Surface(rsa_out_rim4) = {lla_out_rim4};

// Top surface anode

lla_top = newreg; Line Loop(lla_top) = {cpat1, cpat2, cpat3, cpat4};
psa_top = newreg; Plane Surface(psa_top) = {lla_top};

// Make anode volume

sla = newreg; Surface Loop(sla) = {rsa_out_rim1, rsa_out_rim2, rsa_out_rim3, rsa_out_rim4, psa_top, psg_top};
vola = newreg; Volume(vola) = {sla};


// Physical surfaces

// Physical Surfaces = Surfaces to which voltages will be applied (target boundaries in .sif file)

physsurf_a = newreg; Physical Surface(physsurf_a) = {rsa_out_rim1, rsa_out_rim2, rsa_out_rim3, rsa_out_rim4, psa_top, psg_top};
physsurf_ca = newreg; Physical Surface(physsurf_ca) = {rsca_rim1, rsca_rim2, rsca_rim3, rsca_rim4, psca_bo, pshb, psd_bo1, psd_bo2, psd_bo3, psd_bo4};
physsurf_cp = newreg; Physical Surface(physsurf_cp) = {rscp_out_rim1, rscp_out_rim2, rscp_out_rim3, rscp_out_rim4, pscp_up1, pscp_up2, pscp_up3, pscp_up4, rscp_in_rim1, rscp_in_rim2, rscp_in_rim3, rscp_in_rim4, pscp_bo1, pscp_bo2, pscp_bo3, pscp_bo4};

// Physical volumes

physvol_gas = newreg; Physical Volume(physvol_gas) = {volg};
physvol_dielectric = newreg; Physical Volume(physvol_dielectric) = {voldp};
physvol_copperplate = newreg; Physical Volume(physvol_copperplate) = {volcp};
physvol_anode = newreg; Physical Volume(physvol_anode) = {vola};
physvol_cathode = newreg; Physical Volume(physvol_cathode) = {volca};

Coherence;
